==========
COAST_SEARCH
==========


.. image:: https://img.shields.io/pypi/v/coast_search.svg
        :target: https://pypi.python.org/pypi/coast_search

.. image:: https://img.shields.io/travis/zedrem/coast_search.svg
        :target: https://travis-ci.org/zedrem/coast_search

.. image:: https://readthedocs.org/projects/coast-search/badge/?version=latest
        :target: https://coast-search.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




COAST_SEARCH allows you to generate and run queries against the Google Custom Search API.

* Free software: MIT license
* Documentation: https://coast-search.readthedocs.io.


Features
--------
With COAST_SEARCH you can:

* Generate and run queries based on the multi-dimensional search logic outlined by Rainer and Williams in `IST'18`_ 
* Define your own queries to run

.. _IST'18: https://www.sciencedirect.com/science/article/abs/pii/S0950584918302192


Prerequisites
-------------
The tool is built in Python 3 and tested in versions 3.5 and 3.6.

You are required to set up and provide your own API keys and Search Engine ID's for searching against the Google Custom Search API. Details on how to do so can be found `online here`_

.. _online here: https://developers.google.com/custom-search/v1/overview

Installation
------------

To install COAST_SEARCH, run this command in your terminal:

.. code-block:: console

    $ pip install coast_search

This is the preferred method to install COAST_SEARCH, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

To install from source, visit our documentation_.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/

.. _documentation: https://coast-search.readthedocs.io
